# Changelog

The canonical changelog is maintained in the repository root:

- [CHANGELOG.md](https://github.com/arxlang/arxpm/blob/main/CHANGELOG.md)

Releases are generated by semantic-release during CI release workflows.
